/*
 * rstudio.css
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * This program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */

body {
  background-color: #fff;
}

@media (prefers-color-scheme: dark) {
  body {
    background-color: #000;
    color: #fff;
  }

  a, a:visited {
    color: #bb86fc;
  }
}

body, td {
  font-family: Lucida Grande, Lucida Sans Unicode, Helvetica, sans-serif;
  font-size: 11pt;
}

#banner {
  background-color: #e0e2e5;
  margin: 30px 20px 70px 20px;
  padding: 8px;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  overflow: hidden;
}

@media (prefers-color-scheme: dark) {
  #banner {
    background-color: #202225;
  }
}

#logo {
  width: 50%;
  float: left;
}
#licensed-to {
  width: 50%;
  float: right;
  margin-top: 0.5em;
  text-align: right;
}
#license-prefix {
  opacity: 0.6;
  font-weight: normal;
}
#border {
  width: 300px;
  padding: 15px;
  background-color: #f7f8f9;
}
@media (prefers-color-scheme: dark) {
  #border {
    background-color: #202225;
    color: #fff;
  }
}
#image {
  margin-right: -18px;
}

#iewarn {
  color: #888;
  width: 480px;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}

#caption {
  text-align: left;
  border-bottom: 4px solid #e0e2e5;
  padding-bottom: 8px;
  margin-bottom: 8px;
  margin-right: 10px;
  font-size: 16px;
  font-weight: normal;
  width: 250px;
}

#staySignedIn {
  vertical-align: middle;
}

#staySignedInLabel {
  vertical-align: middle;
}

#detail {
  color: #aaa;
  margin-top: 8px;
  margin-right: 10px;
}

a img {
  border: none;
}

#login-html {
  margin: 30px 20px 70px 20px;
  padding: 8px;
}

#skipnav a {
    position: absolute;
    clip: rect(0 0 0 0);
    border: 0;
    height: 1px; margin: -1px;
    overflow: hidden;
    padding: 0;
    width: 1px;
    white-space: nowrap;
}

#skipnav a:focus {
    clip:auto;
    left:0;
    top:0;
    width:100%;
    height:auto;
    margin:0;
    padding:10px 0;
    background:#fdf6e7;
    border:2px solid #990000;
    border-left:none;
    border-right:none;
    text-align:center;
    font-weight:bold;
    color:#990000;
}

.visuallyhidden {
    position: absolute;
    clip: rect(0 0 0 0);
    border: 0;
    width: 1px;
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
}

.signin-spinner-holder {
  width: 300px;
  text-align: center;
  margin: 0 auto;
  padding-top: 10px;
}

/**
* Modified from https://loading.io/css/.
* Released under the CC0 License.
*/

.signin-spinner {
  color: white;
  display: inline-block;
  position: relative;
  width: 20px;
  height: 20px;
  text-align: center;
} 
 
@media (prefers-color-scheme: dark) {
  .signin-spinner {
    color: black;
  }
}

.signin-spinner div {
  transform-origin: 10px 10px;
  animation: signin-spinner 1.2s linear infinite;
}
.signin-spinner div:after {
  content: " ";
  display: inline;
  position: absolute;
  top: 0px;
  left: 9px;
  width: 2px;
  height: 5px;
  background: black;
}
@media (prefers-color-scheme: dark) {
  .signin-spinner div:after {
    background: white;
  }
}

.signin-spinner div:nth-child(1) {
  transform: rotate(0deg);
  animation-delay: -1.1s;
}
.signin-spinner div:nth-child(2) {
  transform: rotate(30deg);
  animation-delay: -1s;
}
.signin-spinner div:nth-child(3) {
  transform: rotate(60deg);
  animation-delay: -0.9s;
}
.signin-spinner div:nth-child(4) {
  transform: rotate(90deg);
  animation-delay: -0.8s;
}
.signin-spinner div:nth-child(5) {
  transform: rotate(120deg);
  animation-delay: -0.7s;
}
.signin-spinner div:nth-child(6) {
  transform: rotate(150deg);
  animation-delay: -0.6s;
}
.signin-spinner div:nth-child(7) {
  transform: rotate(180deg);
  animation-delay: -0.5s;
}
.signin-spinner div:nth-child(8) {
  transform: rotate(210deg);
  animation-delay: -0.4s;
}
.signin-spinner div:nth-child(9) {
  transform: rotate(240deg);
  animation-delay: -0.3s;
}
.signin-spinner div:nth-child(10) {
  transform: rotate(270deg);
  animation-delay: -0.2s;
}
.signin-spinner div:nth-child(11) {
  transform: rotate(300deg);
  animation-delay: -0.1s;
}
.signin-spinner div:nth-child(12) {
  transform: rotate(330deg);
  animation-delay: 0s;
}
@keyframes signin-spinner {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}

.signin-hidden {
  display: none;
}
