$wnd.rstudio.runAsyncCallback17("function q8s(a){this.a=a}\nfunction Pjt(a){this.a=a}\nfunction Rjt(a,b){this.a=a;this.b=b}\nfunction PYu(a,b){this.a=a;this.b=b}\nfunction jZu(a,b){this.a=a;this.b=b}\nfunction Fbw(a,b){Ebw();this.b=a;this.a=b}\nfunction dft(a,b){Kdt();var c;c=a;bLu(c,b.a)}\nfunction qWv(a,b){T3j(a.u,b)}\nfunction WKu(a,b){qWv(a.ub,b)}\nfunction E6s(a){mci(a.n,a.c,null)}\nfunction F6s(a){mci(a.n,a.g,null)}\nfunction k7s(a){B7s(a.o,a.g,AWz,null)}\nfunction p7s(a){B7s(a.o,a.g,'next',null)}\nfunction r7s(a){B7s(a.o,a.g,'prev',null)}\nfunction s7s(a){B7s(a.o,a.g,'refresh',null)}\nfunction G6s(a){mci(a.n,a.g+'?print-pdf',null)}\nfunction A6i(a){return {items:a}}\nfunction PKu(a,b){en((Zm(),Ym),new jZu(a,b))}\nfunction cft(a,b){Kdt();en((Zm(),Ym),new Rjt(b,a))}\nfunction XEh(a){$wnd.desktop.setPresentationUrl(a)}\nfunction T3j(a,b){a.d.navigateToPresentationEditorLocation(b)}\nfunction bLu(a,b){yfw(a.w,wDy,false)?lJu(a,new PYu(a,b)):K1u(a._,b)}\nfunction y6s(a,b){Pte(b.substr(0,4),THx)||(b=q3l(a.p,b));return b}\nfunction D6s(a){!!a.b&&rPh(a.k,new Fbw((pdf(),Hdf(a.b.source_file,false,-1,0)),u6i(a.d,a.a,a.e)),false)}\nfunction v6i(a,b){var c,d,e,f;b==-1&&(b=a.auto_slide_level);f=t6i(a,b,true);for(c=0;c<f.length;c++){e=f[c];for(d=0;d<e.items.length;d++){if(Pte(e.items[d].type,Phy))return c}}return 0}\nfunction u6i(a,b,c){var d,e,f,g,h;c==-1&&(c=b.auto_slide_level);h=t6i(b,c,false);if(a<h.length){g=h[a];zl(g.items,x6i(g.items[0].row))}e=[];for(d=0;d<h.length;d++){g=h[d];for(f=0;f<g.items.length;f++){xl(e,g.items[f])}}return w6i(e,b.auto_slide_level)}\nfunction K1u(a,b){var c,d,e,f,g,h,i;e=J1u(a).items;d=[];for(g=0;g<e.length;g++){h=e[g];Pte(h.type,Phy)||(d[d.length]=h,undefined)}c=-1;i=b.items;for(f=0;f<i.length;f++){if(Pte(i[f].type,Phy)){c=f;break}}if(c>=0){h=d[c];!!h&&o8t(a.a,Ehw(h.row,0),true)}}\nfunction t6i(a,b,c){var d,e,f,g,h,i;i=[];g=a.items;for(d=0;d<g.length;d++){f=g[d];e=i.length==0||Pte(f.type,jFx)||Pte(f.type,'hr')||Pte(f.type,IEx)&&f.level<=b;if(e){h=A6i([]);xl(h.items,f);i[i.length]=h}else (c||!Pte(f.type,Phy))&&xl(i[i.length-1].items,f)}return i}\nfunction H6s(a,b){var c,d;c=b.a;d=y6s(a,c.url);a.o=v6i(b.a.editor_state,b.a.slide_level);a.o==0&&a.d!=0&&(a.o=a.d);iUp(a.j);if(!Pte(d,a.g)||!a.j.o){a.g=d;a.c=d;a.b=c.quarto_navigation;a.a=c.editor_state;a.e=c.slide_level;(ZDh()||!!$wnd.remoteDesktop)&&XEh(a.g);o7s(a.j,a.g,a.b)}else{s7s(a.j)}}\nfunction o7s(a,b,c){var d;(ZDh()||!!$wnd.remoteDesktop)&&(HYe(b)?(Oh(a.d).removeAttribute(Fhy),undefined):(Oh(a.d).setAttribute(Fhy,UUA),undefined));a.b=b;a.o=null;a.g=null;d=Qh(a.d);d>0&&yi(a,new ebf(dO(d*0.6666666666666666)+((a.K?Ph(a.K):0)+(a.O?Ph(a.O):0))));P6d(a.d,a.b);c.is_website?uYl(a.i):tYl(a.i,c.source_file,c.output_file);l8g(a.p)}\nfunction m8s(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=R8s(a.a.b.a);sOp(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.p4b();break;case 2:a.a.a.J.q4b();break;case 3:D6s(a.a.a);break;case 4:k7s(a.a.a.j);break;case 5:p7s(a.a.a.j);break;case 6:E6s(a.a.a);break;case 7:F6s(a.a.a);break;case 8:r7s(a.a.a.j);break;case 9:G6s(a.a.a);break;case 10:H6s(a.a.a,a.b[0]);break;case 11:s7s(a.a.a.j);break;case 12:a.a.a.J.r4b();break;case 13:a.a.a.J.s4b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nsFd(298,1,Kqy);_.jn=function p8s(){m8s((new q8s(this)).a)};sFd(7226,1,oTx,q8s);_.ln=function r8s(){m8s(this.a)};var kKc=dse(7226);sFd(3189,1,jTx,Pjt);_.jw=function Qjt(a){cft(this.a,a)};var cOc=dse(3189);sFd(3188,1,OFx,Rjt);_.ln=function Sjt(){dft(this.a,this.b)};var dOc=dse(3188);sFd(4924,1,oTx,PYu);_.ln=function QYu(){PKu(this.a,this.b)};var X1c=dse(4924);sFd(4923,1,OFx,jZu);_.ln=function kZu(){WKu(this.a,this.b)};var g2c=dse(4923);sFd(3235,xHx,{},Fbw);_.Zn=function Gbw(a){var b,c;b=(c=OOi(a.k,this.b),!!c&&YN(c,78)?c:(IOi(),COi));Qnt(a.b,this.b,b,new Pjt(this))};_._n=function Ibw(){return Dbw};_.$n=function Hbw(){return Dbw};var _id=dse(3235);lDx(fm)(17);\n//# sourceURL=rstudio-17.js\n")
