/*
 *  /MathJax/localization/th/HTML-CSS.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("th","HTML-CSS",{version:"2.7.6",isLoaded:true,strings:{LoadWebFont:"\u0E01\u0E33\u0E25\u0E31\u0E07\u0E42\u0E2B\u0E25\u0E14\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E40\u0E27\u0E47\u0E1A %1",CantLoadWebFont:"\u0E44\u0E21\u0E48\u0E2A\u0E32\u0E21\u0E32\u0E23\u0E16\u0E42\u0E2B\u0E25\u0E14\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E40\u0E27\u0E47\u0E1A %1",FirefoxCantLoadWebFont:"Firefox \u0E44\u0E21\u0E48\u0E2A\u0E32\u0E21\u0E32\u0E23\u0E16\u0E42\u0E2B\u0E25\u0E14\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E40\u0E27\u0E47\u0E1A\u0E08\u0E32\u0E01\u0E42\u0E2E\u0E2A\u0E15\u0E4C\u0E23\u0E30\u0E22\u0E30\u0E44\u0E01\u0E25\u0E44\u0E14\u0E49",CantFindFontUsing:"\u0E44\u0E21\u0E48\u0E2A\u0E32\u0E21\u0E32\u0E23\u0E16\u0E04\u0E49\u0E19\u0E2B\u0E32\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E17\u0E35\u0E48\u0E16\u0E39\u0E01\u0E15\u0E49\u0E2D\u0E07\u0E42\u0E14\u0E22\u0E43\u0E0A\u0E49 %1",WebFontsNotAvailable:"\u0E44\u0E21\u0E48\u0E1E\u0E1A\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E40\u0E27\u0E47\u0E1A \u0E08\u0E30\u0E43\u0E0A\u0E49\u0E41\u0E1A\u0E1A\u0E2D\u0E31\u0E01\u0E29\u0E23\u0E23\u0E39\u0E1B\u0E20\u0E32\u0E1E\u0E41\u0E17\u0E19"}});MathJax.Ajax.loadComplete("[MathJax]/localization/th/HTML-CSS.js");
